Compute the Berger approximate variance estimator (Berger, 1998) Estimator of class 3, it requires only first-order inclusion probabilities but for all population units.
var_Berger(y, pik, sample)a scalar, the estimated variance
numeric vector of sample observations
numeric vector of first-order inclusion probabilities for all population units
Either a numeric vector of length equal to the sample size with
the indices of sample units, or a boolean vector of the same length of pik, indicating which
units belong to the sample (TRUE if the unit is in the sample,
FALSE otherwise.
Only used with estimators of the third class (see Details for more information).