Compute an approximate variance estimate using the class of estimators proposed by Brewer (2002). Estimators of class 3, they require only first-order inclusion probabilities but for all population units.
var_Brewer_class3(y, pik, method, sample)a scalar, the estimated variance
numeric vector of sample observations
numeric vector of first-order inclusion probabilities for all population units
string indicating the desired approximate variance estimator. One of "Deville1", "Deville2", "Deville3", "Hajek", "Rosen", "FixedPoint", "Brewer1", "HartleyRao", "Berger", "Tille", "MateiTille1", "MateiTille2", "MateiTille3", "MateiTille4", "MateiTille5", "Brewer2", "Brewer3", "Brewer4".
Either a numeric vector of length equal to the sample size with
the indices of sample units, or a boolean vector of the same length of pik, indicating which
units belong to the sample (TRUE if the unit is in the sample,
FALSE otherwise.
Only used with estimators of the third class (see Details for more information).