Computes an approximate variance estimate according to one of the estimators proposed by Matei and Tillé (2005) Estimators of class 3, they require only first-order inclusion probabilities but for all population units.
var_MateiTille(y, pik, method, sample, maxIter = 1000, eps = 1e-05)a scalar, the estimated variance
numeric vector of sample observations
numeric vector of first-order inclusion probabilities for all population units
string indicating the desired approximate variance estimator. One of "Deville1", "Deville2", "Deville3", "Hajek", "Rosen", "FixedPoint", "Brewer1", "HartleyRao", "Berger", "Tille", "MateiTille1", "MateiTille2", "MateiTille3", "MateiTille4", "MateiTille5", "Brewer2", "Brewer3", "Brewer4".
Either a numeric vector of length equal to the sample size with
the indices of sample units, or a boolean vector of the same length of pik, indicating which
units belong to the sample (TRUE if the unit is in the sample,
FALSE otherwise.
Only used with estimators of the third class (see Details for more information).
a scalar indicating the maximum number of iterations for the fixed-point procedure
tolerance value for the convergence of the fixed-point procedure